==> eslint-plugin-devops-0.0.1-2.tgz: package/lib/rules/filename-lower-case.js <==
/**
 * @fileoverview vue文件名多单词必须为全小写中划线分隔命名
 * @author fwz
 */
"use strict";

const path = require("path");
//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

/** @type {import('eslint').Rule.RuleModule} */
module.exports = {
  meta: {
    /**
     * 规则的类型 problem|suggestion|layout
     * problem: 这条规则识别的代码可能会导致错误或让人迷惑。应该优先解决这个问题
     * suggestion: 这条规则识别的代码不会导致错误，但是建议用更好的方式
     * layout: 表示这条规则主要关心像空格、分号等这种问题
     */
    type: "suggestion", // `problem`, `suggestion`, or `layout`
    /**
     * 对于自定义规则，docs字段是非必须的
     */
    docs: {
      description: "vue文件名多单词必须为全小写中划线分隔命名",
      recommended: false,
      url: null, // URL to the documentation page for this rule
    },
    /**
     * 标识这条规则是否可以修复，假如没有这属性，即使你在下面那个create方法里实现了fix功能，eslint也不会帮你修复
     */
    fixable: null, // Or `code` or `whitespace`
    /**
     * 这里定义了这条规则需要的参数
     * 比如我们是这样使用带参数的rule的时候，rules: { myRule: ['error', param1, param2....]}
     * error后面的就是参数，而参数就是在这里定义的
     */
    schema: [], // Add a schema if the rule has options
    messages: {
      unexpected: '文件名："{{value}}"多单词必须为全小写中划线分隔命名',
    },
  },
  /**
   * 这是最重要的方法，我们对代码的校验就是在这里做的
   */
  create(context) {
    return {
      "Program:exit"() {
        const fileName = context.getFilename();
        const componentName = path.basename(fileName, path.extname(fileName));
        // 只验证文件后缀为vue的文件
        if (/\.(vue)$/.test(path.extname(fileName))) {
          if (!/^[a-z0-9-.]+$/.test(componentName)) {
            context.report({
              messageId: "unexpected",
              data: {
                value: fileName,
              },
              loc: { line: 1, column: 0 },
            });
          }
        }
      },
    };
  },
};

==> eslint-plugin-devops-0.0.1-3.tgz: package/lib/rules/filename-lower-case.js <==
/**
 * @fileoverview vue文件名多单词必须为全小写中划线分隔命名
 * @author fwz
 */
"use strict";

const path = require("path");
//------------------------------------------------------------------------------
// Rule Definition
//------------------------------------------------------------------------------

/** @type {import('eslint').Rule.RuleModule} */
module.exports = {
  meta: {
    /**
     * 规则的类型 problem|suggestion|layout
     * problem: 这条规则识别的代码可能会导致错误或让人迷惑。应该优先解决这个问题
     * suggestion: 这条规则识别的代码不会导致错误，但是建议用更好的方式
     * layout: 表示这条规则主要关心像空格、分号等这种问题
     */
    type: "suggestion", // `problem`, `suggestion`, or `layout`
    /**
     * 对于自定义规则，docs字段是非必须的
     */
    docs: {
      description: "vue文件名多单词必须为全小写中划线分隔命名",
      recommended: false,
      url: null, // URL to the documentation page for this rule
    },
    /**
     * 标识这条规则是否可以修复，假如没有这属性，即使你在下面那个create方法里实现了fix功能，eslint也不会帮你修复
     */
    fixable: null, // Or `code` or `whitespace`
    /**
     * 这里定义了这条规则需要的参数
     * 比如我们是这样使用带参数的rule的时候，rules: { myRule: ['error', param1, param2....]}
     * error后面的就是参数，而参数就是在这里定义的
     */
    schema: [], // Add a schema if the rule has options
    messages: {
      unexpected: '文件名："{{value}}"多单词必须为全小写中划线分隔命名',
    },
  },
  /**
   * 这是最重要的方法，我们对代码的校验就是在这里做的
   */
  create(context) {
    const WHITE = ['App']
    return {
      "Program:exit"() {
        const fileName = context.getFilename();
        const componentName = path.basename(fileName, path.extname(fileName));
        // 只验证文件后缀为vue的文件
        if (/\.(vue)$/.test(path.extname(fileName))) {
          if (!/^[a-z0-9-.]+$/.test(componentName) && !WHITE.includes(componentName)) {
            context.report({
              messageId: "unexpected",
              data: {
                value: fileName,
              },
              loc: { line: 1, column: 0 },
            });
          }
        }
      },
    };
  },
};
